.bd-page-width {
    max-width: 110rem;
}

.bd-main .bd-content .bd-article-container {
    max-width: 80%;
}

.bd-sidebar-primary {
    width: 20%;
}

body {
    counter-reset: codecell;
}

.cell_input {
    background-color: var(--mystnb-source-border-color) !important;
}

.cell .cell_input::before {
    counter-increment: codecell;
    content: " [" counter(codecell) "]";
    display: block;
    margin-bottom: 0.3rem;
    margin-left: 0.5rem;
    color: var(--pst-color-on-surface);
    font-family: var(--pst-font-family-monospace);
}

